@@ -119,16 +119,16 @@ typedef struct CBinding {
 
 #ifdef __WIN32__
 #if defined(_MSC_VER)
-#   define EXPORT(a) __declspec(dllexport) a
+#   define EXPORT(a,b) __declspec(dllexport) a b
 #else
 #   if defined(__BORLANDC__)
-#	define EXPORT(a) a _export
+#	define EXPORT(a,b) a _export b
 #   endif
 #endif
 #endif
 
 #ifndef EXPORT
-#   define EXPORT(a) a
+#   define EXPORT(a) a b
 #endif
 
 /*
@@ -139,7 +139,7 @@ static int		CBindingEvalProc _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, XEvent *eventPtr,
 			    Tk_Window tkwin, KeySym keySym));
 static void		CBindingFreeProc _ANSI_ARGS_((ClientData clientData));
-EXTERN EXPORT(int)	Tktest_Init _ANSI_ARGS_((Tcl_Interp *interp));
+EXTERN EXPORT(int,Tktest_Init) _ANSI_ARGS_((Tcl_Interp *interp));
 static int		ImageCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
 static int		TestcbindCmd _ANSI_ARGS_((ClientData dummy,
